@@ -2,8 +2,8 @@ import base64
 import time
 
 import grpc
-import registry_pb2
-import registry_pb2_grpc
+import public_registry_pb2
+import public_registry_pb2_grpc
 from tickstore import client
 from tickstore.query import QuerySettings
 
@@ -21,9 +21,9 @@ class Client:
         self.__api_secret = api_secret
         license_id_bytes = base64.b64decode(api_key)
         license_id = int.from_bytes(license_id_bytes, "little")
-        registry_address = "registry.alphaticks.io:7001"
+        registry_address = "registry.alphaticks.io:8021"
         channel = grpc.insecure_channel(registry_address)
-        self.__stub = registry_pb2_grpc.PublicRegistryStub(channel)
+        self.__stub = public_registry_pb2_grpc.StaticStub(channel)
         interceptors = [
             Interceptor(license_id, api_secret)
         ]
@@ -35,17 +35,27 @@ class Client:
         }
 
     def get_securities(self):
-        request = registry_pb2.SecuritiesRequest()
+        request = public_registry_pb2.SecuritiesRequest()
         res = self.__stub.Securities(request)
         return res.securities
 
     def get_assets(self):
-        request = registry_pb2.AssetsRequest()
+        request = public_registry_pb2.AssetsRequest()
         res = self.__stub.Assets(request)
         return res.assets
 
+    def get_protocols(self):
+        request = public_registry_pb2.ProtocolsRequest()
+        res = self.__stub.Protocols(request)
+        return res.protocols
+
+    def get_protocol_assets(self):
+        request = public_registry_pb2.ProtocolAssetsRequest()
+        res = self.__stub.ProtocolAssets(request)
+        return res.protocol_assets
+
     def stream_trade_price(self, sec, batch_size=1000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_LIVE)
+        c = self.get_store(DATA_CLIENT_LIVE)
         now = round(time.time_ns() / 1000000)
         qs = QuerySettings(
             streaming=True,
@@ -60,7 +70,7 @@ class Client:
         return FloatIterator(q)
 
     def stream_funding_rate(self, sec, batch_size=1000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1H)
+        c = self.get_store(DATA_CLIENT_1H)
         now = round(time.time_ns() / 1000000)
         qs = QuerySettings(
             streaming=True,
@@ -75,7 +85,7 @@ class Client:
         return FloatIterator(q)
 
     def stream_liquidation(self, sec, batch_size=1000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1M)
+        c = self.get_store(DATA_CLIENT_1M)
         now = round(time.time_ns() / 1000000)
         qs = QuerySettings(
             streaming=True,
@@ -89,7 +99,7 @@ class Client:
         return TradeIterator(q)
 
     def stream_trade(self, sec, batch_size=1000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_LIVE)
+        c = self.get_store(DATA_CLIENT_LIVE)
         now = round(time.time_ns() / 1000000)
         qs = QuerySettings(
             streaming=True,
@@ -103,7 +113,7 @@ class Client:
         return TradeIterator(q)
 
     def stream_open_interest(self, sec, batch_size=1000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1M)
+        c = self.get_store(DATA_CLIENT_1M)
         now = round(time.time_ns() / 1000000)
         qs = QuerySettings(
             streaming=True,
@@ -120,7 +130,7 @@ class Client:
     def stream_ohlcv(self, sec, freq, batch_size=1000, timeout=100000):
         if not check_frequency(freq):
             raise ValueError("frequency value error")
-        c = self.__get_store(freq)
+        c = self.get_store(freq)
         now = round(time.time_ns() / 1000000)
         qs = QuerySettings(
             streaming=True,
@@ -138,10 +148,10 @@ class Client:
             raise ValueError("frequency value error")
         if freq < DATA_CLIENT_1M:
             raise ValueError("minimum frequency 1m")
-        c = self.__get_store(freq)
+        c = self.get_store(freq)
         now = round(time.time_ns() / 1000000)
-        selector = 'SELECT AggOBLiquidity(obliquidity, "{0}", "{1}", "1000") WHERE ID="{2}" GROUPBY base'\
-                       .format(freq, depth, sec.security_id)
+        selector = 'SELECT AggOBLiquidity(obliquidity, "{0}", "{1}", "1000") WHERE ID="{2}" GROUPBY base' \
+            .format(freq, depth, sec.security_id)
         qs = QuerySettings(
             streaming=True,
             batch_size=batch_size,
@@ -154,7 +164,7 @@ class Client:
         return LiquidityIterator(q)
 
     def get_historical_trade_price(self, sec, frm, to, batch_size=10000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_LIVE)
+        c = self.get_store(DATA_CLIENT_LIVE)
         qs = QuerySettings(
             streaming=False,
             batch_size=batch_size,
@@ -168,7 +178,7 @@ class Client:
         return FloatIterator(q)
 
     def get_historical_funding_rate(self, sec, frm, to, batch_size=10000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1H)
+        c = self.get_store(DATA_CLIENT_1H)
         qs = QuerySettings(
             streaming=False,
             batch_size=batch_size,
@@ -182,7 +192,7 @@ class Client:
         return FloatIterator(q)
 
     def get_historical_liquidation(self, sec, frm, to, batch_size=10000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1M)
+        c = self.get_store(DATA_CLIENT_1M)
         qs = QuerySettings(
             streaming=False,
             batch_size=batch_size,
@@ -195,7 +205,7 @@ class Client:
         return TradeIterator(q)
 
     def get_historical_trade(self, sec, frm, to, batch_size=10000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_LIVE)
+        c = self.get_store(DATA_CLIENT_LIVE)
         qs = QuerySettings(
             streaming=False,
             batch_size=batch_size,
@@ -208,7 +218,7 @@ class Client:
         return TradeIterator(q)
 
     def get_historical_open_interest(self, sec, frm, to, batch_size=10000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1M)
+        c = self.get_store(DATA_CLIENT_1M)
         qs = QuerySettings(
             streaming=False,
             batch_size=batch_size,
@@ -224,7 +234,7 @@ class Client:
     def get_historical_ohlcv(self, sec, freq, frm, to, batch_size=10000, timeout=100000):
         if not check_frequency(freq):
             raise ValueError("frequency value error")
-        c = self.__get_store(freq)
+        c = self.get_store(freq)
         qs = QuerySettings(
             streaming=False,
             batch_size=batch_size,
@@ -237,8 +247,8 @@ class Client:
         return OHLCVIterator(q)
 
     def get_historical_liquidity(self, sec, freq, depth, frm, to, batch_size=10000, timeout=100000):
-        c = self.__get_store(DATA_CLIENT_1M)
-        selector = 'SELECT AggOBLiquidity(obliquidity, "{0}", "{1}", "1000") WHERE ID="{2}" GROUPBY base'\
+        c = self.get_store(DATA_CLIENT_1M)
+        selector = 'SELECT AggOBLiquidity(obliquidity, "{0}", "{1}", "1000") WHERE ID="{2}" GROUPBY base' \
             .format(freq, depth, sec.security_id)
         qs = QuerySettings(
             streaming=False,
@@ -251,7 +261,7 @@ class Client:
         q = c.new_query(qs)
         return LiquidityIterator(q)
 
-    def __get_store(self, freq):
+    def get_store(self, freq):
         min_score = DATA_CLIENT_1H
         cfreq = 0
         for k in self.__stores:
